package de.geodbs;
/**
 * Beispielprogramm zur Demonstration des JDBC-APIs fr PostgreSQL.
 *
 * @author: Thomas Brinkhoff, https://www.geodbs.de/
 * @version: Auflage 4, Abs. 9.2.3
 */

import static de.geodbs.ConnectionParametersPG.*;

import java.sql.*;		// JDBC-Klassen


public class JdbcExamplePG {

public static void main (String[] args) {
	try (Connection db = DriverManager.getConnection(url, user, pw)) {
		// Einfache Anfrage ausfhren
		String sql = "SELECT gkz, name FROM Gemeinden WHERE name LIKE 'O%'";
		try (Statement statement = db.createStatement();
		     ResultSet result = statement.executeQuery(sql)) {
			while (result.next()) {
				System.out.print(result.getInt("gkz") + " - ");
				System.out.println(result.getString(2));
			}
		};
		System.out.println();

		// PreparedStatement ausfhren
		sql = "SELECT name FROM Hochschulen WHERE stud >= ? AND stud < ?";
		try (PreparedStatement prepStmt = db.prepareStatement(sql)) {
			for (int i=0; i<30000; i+=10000) {
				prepStmt.setInt(1,i);
				prepStmt.setInt(2,i+10000);
				ResultSet result = prepStmt.executeQuery();
				System.out.println("zw. "+i+" und "+(i+10000)+" Studierende:");
				while (result.next())
					System.out.println("  "+result.getString("name"));
				result.close();
			}
		}
		System.out.println();

		// Daten verndern
		try ( Statement update = db.createStatement()) {
			int stud = 7000;
			sql = "UPDATE Hochschulen SET stud = "+stud+" WHERE name = 'Jade Hochschule'";
			int n = update.executeUpdate(sql);
			System.out.println("Zahl genderter Datenstze: "+n);
		}
	} // try
	catch (SQLException ex) {
		System.err.println("Fehler beim Datenbankzugriff: "+ex);
	}
}

}
