package de.geodbs;
/**
 * Beispielprogramm zum Zugriff auf PostGIS ber die Klassen PGgeometry und PGgeography.
 *
 * @author: Thomas Brinkhoff, https://www.geodbs.de/
 * @version: Auflage 4, Abs. 9.3.1.3
 */
import static de.geodbs.ConnectionParametersPG.*;		// Verbindungsparameter

import java.sql.*;		// JDBC-Klassen

import net.postgis.jdbc.PGgeography;		// PostGIS-Klassen
import net.postgis.jdbc.PGgeometry;
import net.postgis.jdbc.geometry.Geometry;
import net.postgis.jdbc.geometry.LinearRing;
import net.postgis.jdbc.geometry.MultiPolygon;
import net.postgis.jdbc.geometry.Point;
import net.postgis.jdbc.geometry.Polygon;


public class PGGeometryExample {

public static void main (String[] args) {
	// Verbindung zur Datenbank aufbauen
	try (Connection db = DriverManager.getConnection(url, user, pw)) {
		// ggf. Datentyp von PostGIS und Klasse aus net.postgis.jdbc zuordnen:
		((org.postgresql.PGConnection)db).addDataType("geometry",PGgeometry.class);
		// Rumliche Selektion ausfhren
		Polygon queryPol = new Polygon(
                new LinearRing[] {
                    new LinearRing(
                        new Point[] {
                            new Point(5, 5),
                            new Point(5, 15),
                            new Point(15, 15),
                            new Point(15, 5),
                            new Point(5, 5)
                        }
                    )
                }
            );
		// oder: Polygon queryPol  = new Polygon("POLYGON((5 5,5 15,15 15,15 5,5 5))");
		String sql = "SELECT name, geo FROM GeoDbLand WHERE ST_Intersects(geo,?)";
		
		try (PreparedStatement statement = db.prepareStatement(sql)) {
			statement.setObject(1, new PGgeometry(queryPol));
			ResultSet result = statement.executeQuery();
			while (result.next()) {
				System.out.print(result.getString("name") + " - ");
				// Zugriff auf Geometrie als PGGeometry: 
				PGgeometry geom = (PGgeometry)result.getObject("geo");
				System.out.println(geom.toString());
				if (geom.getGeoType() == Geometry.POLYGON) {
					Polygon pol = (Polygon)geom.getGeometry();
					for (int ri = 0; ri < pol.numRings(); ri++) {
						LinearRing ring = pol.getRing(ri);
						for (int pi = 0; pi < ring.numPoints(); pi++ ) {
							Point point = ring.getPoint(pi);
							System.out.println(point.toString());
						}
					}
				}
			}
			result.close();
		}
		System.out.println();
		
		// Weitere Anfrage mit PGgeometry:
		sql = "SELECT code, name, geom FROM GeoGemeinden";
		try (Statement statement = db.createStatement()) {
			ResultSet result = statement.executeQuery(sql);
			while (result.next()) {
				// Zugriff auf Geometrie als PGGeometry: 
				PGgeometry geom = (PGgeometry)result.getObject("geom");
				System.out.print(result.getString("name") + " - ");
				System.out.println(geom.toString());
			}
			result.close();
		}
		System.out.println();
		
		// Weitere Anfrage mit PGgeography:
		sql = "SELECT vorwahl, name, geog FROM Ortsnetze";
		try (Statement statement = db.createStatement()) {
			ResultSet result = statement.executeQuery(sql);
			while (result.next()) {
				// Zugriff auf Geometrie als PGgeography: 
				PGgeography geom = (PGgeography)result.getObject("geog");
				if (geom.getGeoType() == Geometry.MULTIPOLYGON) {
					MultiPolygon pol = (MultiPolygon)geom.getGeometry();
					if (pol.numGeoms() > 1) {
						System.out.print(result.getString("name") + " - ");
						System.out.println(geom.toString());
					}
				}
			}
			result.close();
		}
	} // try
	catch (SQLException ex) {
		System.err.println("Fehler beim Datenbankzugriff: "+ex);
	}
}

}
